@@ -2,8 +2,11 @@
 
     """
 
+import sys
+
 from .auto import make_venv
 
 
 if __name__ == '__main__' :
-    make_venv()
+    conf_fp = sys.argv[1]
+    make_venv(conf_fp)
